@@ -741,9 +741,6 @@ test_watch_cancels (Test *test,
 int
 main (int argc, char **argv)
 {
-#if !GLIB_CHECK_VERSION(2,35,0)
-	g_type_init ();
-#endif
 	g_test_init (&argc, &argv, NULL);
 	g_set_prgname ("test-system-prompt");
 
